.. _translate-toolkit:

Translate Toolkit
=================

Welcome to Translate Toolkit's documentation. This documentation covers both
user's and programmer's perspective.

User's Guide
------------

This part has the user's documentation for the tools included in the
Translate Toolkit.


Developer's Guide
-----------------

If you are a developer interested in using the Translate Toolkit for
building new tools, make sure to read through this part.

Additional Notes
----------------

Changelog and legal information are included here.

API Reference
-------------

This part covers any function, class or method included within the
Translate Toolkit that you can use to programatically build new
localization tools.

.. toctree::
   :maxdepth: 1
   :caption: User's Guide
   :hidden:

   features
   installation
   commands/index
   guides/index
   Supported formats <formats/index>



.. toctree::
   :maxdepth: 1
   :caption: Developer's Guide
   :hidden:

   developers/styleguide
   developers/testing
   developers/contributing
   developers/reporting_bugs
   developers/developers
   developers/releasing
   developers/deprecation


.. toctree::
   :maxdepth: 1
   :caption: Additional Notes
   :hidden:

   releases/index
   history
   license


.. toctree::
   :maxdepth: 2
   :caption: API Reference
   :hidden:

   api/index
   api/convert
   api/filters
   api/lang
   api/misc
   api/search
   api/services
   api/storage
   api/tools
